package tagext;

import java.util.Iterator;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

import rss.RssFeed;
import rss.RssReader;

/**
 * A tag that provides iteration over the items in an RSS feed.
 *
 * @author      Simon Brown
 */
public class RssFeedTag extends TagSupport {

  /** the URL of the RSS feed */
  private String url;

  /** the iterator instance used to loop over all RSS items */
  private Iterator iterator;

  /**
   * Called when the starting tag is encountered.
   *
   * @return  EVAL_BODY_INCLUDE or SKIP_BODY, depending whether there
   *          are items or not
   * @throws  JspException    if something goes wrong
   */
  public int doStartTag() throws JspException {
    RssReader reader = new RssReader();
    RssFeed feed = reader.read(url);
    iterator = feed.getItems().iterator();

    if (iterator.hasNext()) {
      pageContext.setAttribute("rssItem", iterator.next());
      return EVAL_BODY_INCLUDE;
    } else {
      return SKIP_BODY;
    }
  }

  /**
   * Called after the body of the tag has been evaluated.
   *
   * @return  EVAL_BODY_AGAIN or SKIP_BODY, depending whether there
   *          are items or not
   * @throws  JspException    if something goes wrong
   */
  public int doAfterBody() throws JspException {
    if (iterator.hasNext()) {
      pageContext.setAttribute("rssItem", iterator.next());
      return EVAL_BODY_AGAIN;
    } else {
      return SKIP_BODY;
    }
  }

  /**
   * Sets the URL attribute.
   *
   * @param url   the URL as a String
   */
  public void setUrl(String url) {
    this.url = url;
  }

}